==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Calendario predefinito"

, "The default calendar to create new events in."
: "Il calendario predefinito per la creazione di nuovi eventi"

, "Default Task List"
: "Elenco Attività predefinito"

, "The default task list to create new tasks in."
: "Lista predefinita di attività in cui crearne una nuova."

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Device"
 ,"Device"

]
, "Devices"
: "Device"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Seleziona un Device"

, "No ActiveSync Device registered"
: "Nessun Device registrato in ActiveSync"

, "Set as {0} Filter"
: "Imposta come filtro {0}"

, "Resetted Sync Filter"
: "Filtro Sync Resettato"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filtro per il dispositivo \"{1}\" è ora \"{2}\""

, "resetted"
: "resettato"

, "Set Sync Filter"
: "Imposta Filtro Sync"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "Politica predefinita"

, "Default Policy installed during setup"
: "Politica predefinita installata durante il setup"

, "Default policy for new devices"
: "Politica predefinita per i nuovi device"

, "Enter the id of the policy to apply to newly created devices."
: "Inserisci l'ID della politica da applicare ai nuovi device"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Disattiva log degli accessi"

, "Disable ActiveSync Access Log creation."
: "Disabilita la creazione del log degli accessi ActiveSync."

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Periodo di sincronizzazione degli eventi"

, "For how long in the past the events should be synchronized."
: "Per quanto tempo nel passato dovrebbero essere sincronizzati gli eventi."

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""





, "Sync Device"
: ""

, "Device"
: "Device"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Seleziona un Device"

, "No ActiveSync Device registered"
: "Nessun Device registrato in ActiveSync"

, "Set as {0} Filter"
: "Imposta come filtro {0}"

, "Resetted Sync Filter"
: "Filtro Sync Resettato"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filtro per il dispositivo \"{1}\" è ora \"{2}\""

, "resetted"
: "resettato"

, "Set Sync Filter"
: "Imposta Filtro Sync"

, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Device Type"
: ""

, "Owner"
: "Proprietario"

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Modello"

, "IMEI"
: ""

, "Friendly Name"
: "Nomignolo"

, "Operating System"
: ""

, "OS Language"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: "Ping Cartella"

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: "Conferma"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Ricerca veloce"

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Device"
 ,"Device"

]
, "Devices"
: "Device"

, "Devicetype"
: ""

, "OS"
: ""

, "Phonenumber"
: "Telefono"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Calendario predefinito"

, "The default calendar to create new events in."
: "Il calendario predefinito per la creazione di nuovi eventi"

, "Default Task List"
: "Elenco Attività predefinito"

, "The default task list to create new tasks in."
: "Lista predefinita di attività in cui crearne una nuova."

, "Default policy for new devices"
: "Politica predefinita per i nuovi device"

, "Enter the id of the policy to apply to newly created devices."
: "Inserisci l'ID della politica da applicare ai nuovi device"

, "Device Model Agent Deny List"
: ""

, "Array of regular expressions of Device-Model strings"
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Disattiva log degli accessi"

, "Disable ActiveSync Access Log creation."
: "Disabilita la creazione del log degli accessi ActiveSync."

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Periodo di sincronizzazione degli eventi"

, "For how long in the past the events should be synchronized."
: "Per quanto tempo nel passato dovrebbero essere sincronizzati gli eventi."

, "%1$s ActiveSync failure"
: ""

, "Dear user,"
: ""

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: ""

, "Thank you."
: ""

, "Your %1$s Team"
: ""

, "Default Policy"
: "Politica predefinita"

, "Default Policy installed during setup"
: "Politica predefinita installata durante il setup"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""





, "Sync Device"
: ""

, "Device"
: "Device"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
